@@ -1,3 +1,7 @@
+from __future__ import annotations
+
+from typing import Optional
+
 from datetime import date as Date
 
 from pydantic import Field, field_serializer
@@ -8,9 +12,9 @@ from ..request import BaseRequest
 class CheckFilter(BaseRequest):
     """Фильтр для получения информации о чеке"""
 
-    order_uuid: str | None = Field(..., description="Идентификатор заказа")
-    cdek_number: str | None = Field(..., description="Номер заказа СДЭК")
-    date: Date | None = Field(
+    order_uuid: Optional[str] = Field(..., description="Идентификатор заказа")
+    cdek_number: Optional[str] = Field(..., description="Номер заказа СДЭК")
+    date: Optional[Date] = Field(
         ..., description="Дата создания чека в формате YYYY-MM-DD"
     )
 
