@@ -1,5 +1,7 @@
 from __future__ import annotations
 
+from typing import Optional
+
 from pydantic import Field
 
 from ..request import BaseRequest
@@ -7,18 +9,18 @@ from .item import Item
 
 
 class CalcPackage(BaseRequest):
-    weight: int | None = Field(None, description="Вес упаковки в граммах")
-    length: int | None = Field(None, description="Длина упаковки в сантиметрах")
-    width: int | None = Field(None, description="Ширина упаковки в сантиметрах")
-    height: int | None = Field(None, description="Высота упаковки в сантиметрах")
+    weight: Optional[int] = Field(None, description="Вес упаковки в граммах")
+    length: Optional[int] = Field(None, description="Длина упаковки в сантиметрах")
+    width: Optional[int] = Field(None, description="Ширина упаковки в сантиметрах")
+    height: Optional[int] = Field(None, description="Высота упаковки в сантиметрах")
 
 
 class Package(CalcPackage):
     number: str = Field(..., description="Номер упаковки")
     weight: int = Field(..., description="Вес упаковки в граммах")
-    commnet: str | None = Field(None, description="Комментарий к упаковке")
-    items: list[Item] | None = Field(None, description="Позиции товаров в упаковке")
-    package_id: str | None = Field(
+    commnet: Optional[str] = Field(None, description="Комментарий к упаковке")
+    items: Optional[list[Item]] = Field(None, description="Позиции товаров в упаковке")
+    package_id: Optional[str] = Field(
         None, description="Уникальный номер упаковки в ИС СДЭК"
     )
 
